# August 1, 2023 - Version 1.1.8

## Summary

---

**✈️ Recommendation Component Released!**

Please update PrismStudio via

```python
pip install prismstudio --upgrade
```

or

```python
pip install prismstudio==1.1.8
```

## August 1, 2023 -
PrismStudio 1.1.8

---

### FEATURES

- **Recommendation Component Released!**
    Recommendation data component in estimate is released!
    Please refer to [Recommendation Component](<#prism.estimate.recommendation>)


